==> calculate-update-3.2.0.tar.bz2: calculate-update-3.2.0/update/utils/cl_setup_update.py <==
#-*- coding: utf-8 -*-

# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import sys
from calculate.core.server.func import Action, Tasks
from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
from calculate.lib.utils.files import FilesError
from calculate.update.update import UpdateError
from calculate.update.package_tools import GitError

setLocalTranslate('cl_update3', sys.modules[__name__])
__ = getLazyLocalTranslate(_)


class ClSetupUpdateAction(Action):
    """
    Действие для настройки параметров автопроверки обновлений
    """
    # ошибки, которые отображаются без подробностей
    native_error = (FilesError, UpdateError, GitError)

    successMessage = __("Updates autocheck settings configured!")
    failedMessage = __("Failed to configure the updates autocheck settings!")
    interruptMessage = __("Configuration manually interrupted")


    # список задач для дейсвия
    tasks = [
        {'name': 'set_variables',
         'method': 'Update.setAutocheckParams(cl_update_autocheck_set,'
                                             'cl_update_autocheck_interval)'}
        ]

==> calculate-update-3.2.1.tar.bz2: calculate-update-3.2.1/update/utils/cl_setup_update.py <==
#-*- coding: utf-8 -*-

# Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import sys
from calculate.core.server.func import Action, Tasks
from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
from calculate.lib.utils.files import FilesError
from calculate.update.update import UpdateError
from calculate.update.package_tools import GitError

setLocalTranslate('cl_update3', sys.modules[__name__])
__ = getLazyLocalTranslate(_)


class ClSetupUpdateAction(Action):
    """
    Действие для настройки параметров автопроверки обновлений
    """
    # ошибки, которые отображаются без подробностей
    native_error = (FilesError, UpdateError, GitError)

    successMessage = __("Updates autocheck configured!")
    failedMessage = __("Failed to configure the updates autocheck procedure!")
    interruptMessage = __("Configuration manually interrupted")


    # список задач для дейсвия
    tasks = [
        {'name': 'set_variables',
         'method': 'Update.setAutocheckParams(cl_update_autocheck_set,'
                                             'cl_update_autocheck_interval)'}
        ]
